@@ -2,6 +2,7 @@ from tornado import web, httpclient, ioloop, httputil
 import os
 import aiohttp
 import socket
+import subprocess
 from simpervisor import SupervisedProcess
 from datetime import datetime
 from asyncio import Lock
@@ -382,10 +383,40 @@ class RemoteProxyHandler(ProxyHandler):
 class SuperviseAndProxyHandler(LocalProxyHandler):
     '''Manage a given process and requests to it '''
 
+    error_template = """<!DOCTYPE html>
+<html>
+    <head>
+        <title>Error report from ContainDS Dashboards</title>
+    </head>
+    <body>
+
+<h2>Error report from ContainDS Dashboards</h2>
+
+    <h3>Command Running:</h2>
+    <pre>
+{cmd}
+    </pre>
+
+    <h3>Error output:</h3>
+    <pre>
+{stderr}
+    </pre>
+
+    <h3>Standard output:</h3>
+    <pre>
+{stdout}
+    </pre>
+    
+    </body>
+</html>"""
+
     def __init__(self, *args, **kwargs):
         self.requested_port = 0
         self.mappath = {}
 
+        self.stderr_str = None
+        self.stdout_str = None
+
         super().__init__(*args, **kwargs)
 
     def initialize(self, state, authtype, *args, **kwargs):
@@ -465,7 +496,8 @@ class SuperviseAndProxyHandler(LocalProxyHandler):
 
                 self.log.info(cmd)
 
-                proc = SupervisedProcess(self.name, *cmd, env=server_env, ready_func=self._http_ready_func, ready_timeout=timeout, log=self.log)
+                proc = SupervisedProcess(self.name, *cmd, env=server_env, ready_func=self._http_ready_func, ready_timeout=timeout, log=self.log,
+                                            stderr=subprocess.PIPE, stdout=subprocess.PIPE)
                 self.state['proc'] = proc
 
                 try:
@@ -474,12 +506,32 @@ class SuperviseAndProxyHandler(LocalProxyHandler):
                     is_ready = await proc.ready()
 
                     if not is_ready:
+
+                        #if proc._restart_process_future:
+                        #    proc._restart_process_future.cancel()
+
+                        self.stderr_str = None
+                        self.stdout_str = None
+
+                        stderr, stdout = await proc.proc.communicate()
+
+                        if stderr:
+                            self.stderr_str = str(stderr.decode("utf-8"))
+                            self.log.info('Process {} failed with stderr: {}'.format(self.name, self.stderr_str))
+
+                        if stdout:
+                            self.stdout_str = str(stdout.decode("utf-8"))
+                            self.log.info('Process {} failed with stdout: {}'.format(self.name, self.stdout_str))
+
                         await proc.kill()
-                        raise web.HTTPError(500, 'could not start {} in time'.format(self.name))
+
+                        del self.state['proc']
+                        return False
                 except:
                     # Make sure we remove proc from state in any error condition
                     del self.state['proc']
                     raise
+            return True
 
     @web.authenticated
     async def oauth_proxy(self, port, path):
@@ -495,11 +547,15 @@ class SuperviseAndProxyHandler(LocalProxyHandler):
             else:
                 path = self.mappath.get(path, path)
 
-        self.log.debug('In proxy')
-
-        await self.ensure_process()
-
-        self.log.debug('In proxy ensured process')
+        if not await self.ensure_process():
+            from tornado.escape import xhtml_escape
+            html = self.error_template.format(
+                cmd=xhtml_escape(" ".join(self.get_cmd())),
+                stderr=xhtml_escape(self.stderr_str or 'None'),
+                stdout=xhtml_escape(self.stdout_str or 'None')
+            )
+            self.set_status(500)
+            return self.write(html)
 
         return await super().proxy(self.port, path)
 
@@ -514,8 +570,9 @@ class SuperviseAndProxyHandler(LocalProxyHandler):
         return await self.proxy(self.port, path)
 
     async def open(self, path):
-        await self.ensure_process()
-        return await super().open(self.port, path)
+        if await self.ensure_process():
+            return await super().open(self.port, path)
+        raise web.HTTPError(500, 'could not start {} in time'.format(self.name))
 
     def post(self, path):
         return self.proxy(self.port, path)
